==> jc-1.4.0.tar.gz: gnu/regexp/REMatchEnumeration.h <==
// public class gnu.regexp.REMatchEnumeration

// class file dependencies
// @dep_class fe05ec85893e59c5 gnu_regexp_REMatchEnumeration
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_REMatchEnumeration_H_
#define _JC_gnu_regexp_REMatchEnumeration_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_RE$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_REMatchEnumeration$sub_refs	_jc_gnu_regexp_REMatchEnumeration$sub_refs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$sub_nonrefs	_jc_gnu_regexp_REMatchEnumeration$sub_nonrefs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$refs	_jc_gnu_regexp_REMatchEnumeration$refs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$nonrefs	_jc_gnu_regexp_REMatchEnumeration$nonrefs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$object	_jc_gnu_regexp_REMatchEnumeration$object;

typedef struct _jc_gnu_regexp_REMatchEnumeration$fields_struct	_jc_gnu_regexp_REMatchEnumeration$fields_struct;
typedef const struct _jc_gnu_regexp_REMatchEnumeration$vmethods	_jc_gnu_regexp_REMatchEnumeration$vmethods;
typedef const struct _jc_gnu_regexp_REMatchEnumeration$vtable	_jc_gnu_regexp_REMatchEnumeration$vtable;
typedef const struct _jc_gnu_regexp_REMatchEnumeration$vtype	_jc_gnu_regexp_REMatchEnumeration$vtype;

// Class fields structure
struct _jc_gnu_regexp_REMatchEnumeration$fields_struct {
	jint	MAYBE;
	jint	NO;
	jint	YES;
};
extern _jc_gnu_regexp_REMatchEnumeration$fields_struct _jc_gnu_regexp_REMatchEnumeration$class_fields;

// Constructors
extern void _jc_gnu_regexp_REMatchEnumeration$method$_init$fdadd6b20d3cb9d3(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *, struct _jc_gnu_regexp_RE$object *, struct _jc_object *, jint, jint);

// Virtual methods
extern jboolean _jc_gnu_regexp_REMatchEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
extern jboolean _jc_gnu_regexp_REMatchEnumeration$method$hasMoreMatches$9c243ab8904f0782(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
extern jboolean _jc_gnu_regexp_REMatchEnumeration$method$hasMoreMatches$aadb77cb61224437(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *, struct _jc_java_lang_StringBuffer$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_regexp_REMatchEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
extern struct _jc_gnu_regexp_REMatch$object *_jc_gnu_regexp_REMatchEnumeration$method$nextMatch$c2c18e949e4e0e78(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$hasMoreMatches$9c243ab8904f0782;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$hasMoreMatches$aadb77cb61224437;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$nextMatch$c2c18e949e4e0e78;

// Virtual methods structure
struct _jc_gnu_regexp_REMatchEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
	jboolean	(*hasMoreMatches$9c243ab8904f0782)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
	jboolean	(*hasMoreMatches$aadb77cb61224437)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *, struct _jc_java_lang_StringBuffer$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
	struct _jc_gnu_regexp_REMatch$object	*(*nextMatch$c2c18e949e4e0e78)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *);
};

// Vtable
struct _jc_gnu_regexp_REMatchEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REMatchEnumeration$vmethods	gnu_regexp_REMatchEnumeration;
};

// Vtype
struct _jc_gnu_regexp_REMatchEnumeration$vtype {
	_jc_type			type;
	_jc_gnu_regexp_REMatchEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_REMatchEnumeration$sub_refs {
	struct _jc_gnu_regexp_REMatch$object	*match;
	struct _jc_gnu_regexp_RE$object	*expr;
	struct _jc_object	*input;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_REMatchEnumeration$refs {
    _jc_gnu_regexp_REMatchEnumeration$sub_refs	gnu_regexp_REMatchEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_REMatchEnumeration$sub_nonrefs {
	jint	more;
	jint	eflags;
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_REMatchEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REMatchEnumeration$sub_nonrefs	gnu_regexp_REMatchEnumeration;
};

// Object instance structure
struct _jc_gnu_regexp_REMatchEnumeration$object {
	_jc_gnu_regexp_REMatchEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_REMatchEnumeration$vtype	*vtype;
	_jc_gnu_regexp_REMatchEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_REMatchEnumeration$vtype _jc_gnu_regexp_REMatchEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_REMatchEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_REMatchEnumeration$class_object;

#endif	/* _JC_gnu_regexp_REMatchEnumeration_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/REMatchEnumeration.h <==
// public class gnu.regexp.REMatchEnumeration

// class file dependencies
// @dep_class fe05ec85893e59c5 gnu_regexp_REMatchEnumeration
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_REMatchEnumeration_H_
#define _JC_gnu_regexp_REMatchEnumeration_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_RE$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_REMatchEnumeration$sub_refs	_jc_gnu_regexp_REMatchEnumeration$sub_refs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$sub_nonrefs	_jc_gnu_regexp_REMatchEnumeration$sub_nonrefs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$refs	_jc_gnu_regexp_REMatchEnumeration$refs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$nonrefs	_jc_gnu_regexp_REMatchEnumeration$nonrefs;
typedef struct _jc_gnu_regexp_REMatchEnumeration$object	_jc_gnu_regexp_REMatchEnumeration$object;

typedef struct _jc_gnu_regexp_REMatchEnumeration$fields_struct	_jc_gnu_regexp_REMatchEnumeration$fields_struct;
typedef const struct _jc_gnu_regexp_REMatchEnumeration$vmethods	_jc_gnu_regexp_REMatchEnumeration$vmethods;
typedef const struct _jc_gnu_regexp_REMatchEnumeration$vtable	_jc_gnu_regexp_REMatchEnumeration$vtable;
typedef const struct _jc_gnu_regexp_REMatchEnumeration$vtype	_jc_gnu_regexp_REMatchEnumeration$vtype;

// Class fields structure
struct _jc_gnu_regexp_REMatchEnumeration$fields_struct {
	jint	MAYBE;
	jint	NO;
	jint	YES;
};
extern _jc_gnu_regexp_REMatchEnumeration$fields_struct _jc_gnu_regexp_REMatchEnumeration$class_fields;

// Constructors
extern void _jc_gnu_regexp_REMatchEnumeration$method$_init$fdadd6b20d3cb9d3(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *, struct _jc_gnu_regexp_RE$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_regexp_REMatchEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_REMatchEnumeration$method$hasMoreMatches$9c243ab8904f0782(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_REMatchEnumeration$method$hasMoreMatches$aadb77cb61224437(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_regexp_REMatchEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_gnu_regexp_REMatch$object *_jc_gnu_regexp_REMatchEnumeration$method$nextMatch$c2c18e949e4e0e78(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$hasMoreMatches$9c243ab8904f0782;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$hasMoreMatches$aadb77cb61224437;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_gnu_regexp_REMatchEnumeration$method_info$nextMatch$c2c18e949e4e0e78;

// Virtual methods structure
struct _jc_gnu_regexp_REMatchEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
	jboolean	(*hasMoreMatches$9c243ab8904f0782)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
	jboolean	(*hasMoreMatches$aadb77cb61224437)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_gnu_regexp_REMatch$object	*(*nextMatch$c2c18e949e4e0e78)(_jc_env *, struct _jc_gnu_regexp_REMatchEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_REMatchEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REMatchEnumeration$vmethods	gnu_regexp_REMatchEnumeration;
};

// Vtype
struct _jc_gnu_regexp_REMatchEnumeration$vtype {
	_jc_type			type;
	_jc_gnu_regexp_REMatchEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_REMatchEnumeration$sub_refs {
	struct _jc_gnu_regexp_REMatch$object	*match;
	struct _jc_gnu_regexp_RE$object	*expr;
	struct _jc_object	*input;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_REMatchEnumeration$refs {
    _jc_gnu_regexp_REMatchEnumeration$sub_refs	gnu_regexp_REMatchEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_REMatchEnumeration$sub_nonrefs {
	jint	more;
	jint	eflags;
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_REMatchEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REMatchEnumeration$sub_nonrefs	gnu_regexp_REMatchEnumeration;
};

// Object instance structure
struct _jc_gnu_regexp_REMatchEnumeration$object {
	_jc_gnu_regexp_REMatchEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_REMatchEnumeration$vtype	*vtype;
	_jc_gnu_regexp_REMatchEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_REMatchEnumeration$vtype _jc_gnu_regexp_REMatchEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_REMatchEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_REMatchEnumeration$class_object;

#endif	/* _JC_gnu_regexp_REMatchEnumeration_H_ */
